Changelog
=========


0.9.2 (2017-02-27)
------------------

- Small modification for the order of the zcml attributes
- Auto add a new line to the end of the prettified files
- Self heal open self closing tag.
  [ale-rt]


0.9.1.1 (2017-02-18)
--------------------

- Fixed bad release.
  [ale-rt]


0.9.1 (2017-02-18)
------------------

- Initial support for zcml style guide (#3).
  [ale-rt]


0.9.0 (2017-02-11)
------------------

- Initial release.
  [ale-rt]
